@@ -1,10 +1,14 @@
 import os
-import GPUtil
 import psutil
 from tabulate import tabulate
 from datetime import datetime
 import platform
 
+def clear():
+	if os.name == 'nt':
+		os.system('cls')
+	else:
+		os.system('clear')
 #Regsitry functions below
 def RegistryAdd(file, value):
 	reg = open('sysfile/registry/' + file, 'w')
@@ -31,7 +35,7 @@ def KernelKillProc(proc):
 	if os.name == 'nt':
 		os.system(f'taskkill /f /IM {proc}')
 	else:
-		os.system(f'kill {proc}')
+		os.system(f'pkill {proc}')
 def KernelRebootSystem():
 	if os.name == 'nt':
 		os.system('shutdown -r -t 0')
